/**
 * Copyright 2012 OW2 Shelbie
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.shelbie.core.internal.handler;

import org.apache.felix.gogo.commands.Action;
import org.apache.felix.gogo.commands.Argument;
import org.apache.felix.gogo.commands.Command;
import org.apache.felix.gogo.commands.Option;
import org.apache.felix.ipojo.InstanceManager;
import org.apache.felix.service.command.CommandSession;
import org.mockito.Mock;
import org.mockito.Spy;
import org.ow2.shelbie.core.IConverterManager;
import org.testng.annotations.BeforeMethod;
import org.testng.annotations.Test;

import static java.util.Arrays.asList;
import static org.mockito.Matchers.eq;
import static org.mockito.Mockito.never;
import static org.mockito.Mockito.verify;
import static org.mockito.Mockito.when;
import static org.mockito.MockitoAnnotations.initMocks;
import static org.testng.Assert.assertEquals;
import static org.testng.Assert.assertSame;

/**
 * A {@code StatelessGogoCommandTestCase} is ...
 *
 * @author Guillaume Sauthier
 */
public class StatefulGogoCommandTestCase {
    
    private StatefulGogoCommand command;
    
    @Mock
    private InstanceManager manager;
    
    @Mock
    private IConverterManager converter;

    @Mock
    private CommandSession session;
    
    @Mock
    private Action action;
    
    @Spy
    private GogoPreparator preparator = new GogoPreparator();

    @BeforeMethod
    public void setUp() throws Exception {
        initMocks(this);
        preparator.bindConverterManager(converter);
        command = new StatefulGogoCommand(manager, preparator);
    }

    @Test
    public void testCreateNewActionReturnsAlwaysTheSameInstance() throws Exception {
        when(manager.getPojoObject()).thenReturn(action);

        // Always return the same instance
        assertSame(command.createNewAction(), action);
        assertSame(command.createNewAction(), action);
        assertSame(command.createNewAction(), action);
        assertSame(command.createNewAction(), action);
    }

    @Test
    public void testRelease() throws Exception {
        when(manager.getPojoObject()).thenReturn(action);
        command.createNewAction();
        command.release();
        verify(manager, never()).deletePojoObject(eq(action));
    }

    @Test
    public void testSuccessiveExecutions() throws Exception {
        HelloAction action = new HelloAction();
        when(manager.getPojoObject()).thenReturn(action);
        when(converter.convert(eq(String.class), eq("fr"))).thenReturn("fr");
        when(converter.convert(eq(String.class), eq("Guillaume"))).thenReturn("Guillaume");

        assertEquals(command.execute(session, asList((Object) "--lang", "fr", "Guillaume")), 1);
        assertEquals(command.execute(session, asList((Object) "--lang", "fr", "Guillaume")), 2);
        assertEquals(command.execute(session, asList((Object) "--lang", "fr", "Guillaume")), 3);
    }

    @Command(scope = "test",
             name = "hello")
    private static class HelloAction implements Action {

        @Option(name = "--lang",
                required = true)
        String lang;

        @Argument
        String target;

        int count = 0;
        
        public Object execute(CommandSession session) throws Exception {
            return ++count;
        }
    }
}
